==> zio-aws-networkmanager_3-5.17.155.1-sources.jar: zio/aws/networkmanager/model/GetCoreNetworkPolicyResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetCoreNetworkPolicyResponse(
    coreNetworkPolicy: Option[zio.aws.networkmanager.model.CoreNetworkPolicy] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse = {
    import GetCoreNetworkPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
      .builder()
      .optionallyWith(coreNetworkPolicy.map(value => value.buildAwsValue()))(
        _.coreNetworkPolicy
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly =
    zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse
      .wrap(buildAwsValue())
}
object GetCoreNetworkPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse =
      zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse(
        coreNetworkPolicy.map(value => value.asEditable)
      )
    def coreNetworkPolicy
        : Option[zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly]
    def getCoreNetworkPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly
    ] = AwsError.unwrapOptionField("coreNetworkPolicy", coreNetworkPolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ) extends zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly {
    override val coreNetworkPolicy
        : Option[zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly] =
      scala
        .Option(impl.coreNetworkPolicy())
        .map(value =>
          zio.aws.networkmanager.model.CoreNetworkPolicy.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ): zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-5.19.8.3-sources.jar: zio/aws/networkmanager/model/GetCoreNetworkPolicyResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetCoreNetworkPolicyResponse(
    coreNetworkPolicy: Optional[
      zio.aws.networkmanager.model.CoreNetworkPolicy
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse = {
    import GetCoreNetworkPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
      .builder()
      .optionallyWith(coreNetworkPolicy.map(value => value.buildAwsValue()))(
        _.coreNetworkPolicy
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly =
    zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse
      .wrap(buildAwsValue())
}
object GetCoreNetworkPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse =
      zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse(
        coreNetworkPolicy.map(value => value.asEditable)
      )
    def coreNetworkPolicy
        : Optional[zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly]
    def getCoreNetworkPolicy: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly
    ] = AwsError.unwrapOptionField("coreNetworkPolicy", coreNetworkPolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ) extends zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly {
    override val coreNetworkPolicy
        : Optional[zio.aws.networkmanager.model.CoreNetworkPolicy.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.coreNetworkPolicy())
        .map(value =>
          zio.aws.networkmanager.model.CoreNetworkPolicy.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetCoreNetworkPolicyResponse
  ): zio.aws.networkmanager.model.GetCoreNetworkPolicyResponse.ReadOnly =
    new Wrapper(impl)
}
